#!/usr/bin/perl -w
#
# srif.pl - v0.2 
# This is a Perl script to process file requests via an
# incoming SRIF file
#
#  Copyright (c) 2001-2002 Robert James Clay 
#  All Rights Reserved. This is free software;  you can redistribute
#  it and/or modify it under the same terms as Perl itself.


# Setup

use strict;
use File::Copy;

use FTN::Utility qw(&logging);

my ($SRIFFILE, $RequestFile, $ResponseFile, $ReqCount,
    @Akas, %SRIF, $SRIF, @FREQ);

my $PublicDir = "/var/local/pub/";	#  base public directory

#
my $Debug = 1;		# set debug flag to true (1) or false (0)
my $LogFile = "/opt/ftn/srifpl/srif.log";	# set log file
my $MagicFile = "/opt/ftn/srifpl/doc/magic.txt";
# sent if file(s) requested isn't found
my $DefaultFile = "/opt/ftn/srifpl/doc/freqerr.txt";

# No user serviceable parts inside

&commandline();

&parsesrif();

&readRequestList();

&sendResponse();

&cleanup();

############################################
# subroutines
############################################

############################################
# process command line arguments.
############################################
sub commandline {

    my ($cmdline) = join(" ", @ARGV);

    logged("Cmd line is $cmdline") if ($Debug);

# this is supposed to verify if correct number of parameters were passed.
# and exit if the more than or less than one parameter
#    if (@ARGV < 1) { exit(1) ; }  

    $SRIFFILE = pop @ARGV;

    copy($SRIFFILE,"/opt/tst/work/SRIFTEST.srf") if ($Debug);

}


############################################
# parse SRIF file
############################################
sub parsesrif {

    my ($keyword, $value);
    
    logged("Parseing SRIF file $SRIFFILE") if ($Debug);
    
    open (SRFFILE, "<$SRIFFILE") or die ("Could not open SRIF file $SRIFFILE.");
        while (<SRFFILE>) {    
	    ($keyword, $value) = split(' ', $_, 2);
	    logged("$keyword:  $value") if ($Debug);
	    if ($keyword ne "AKA") {
		$SRIF{$keyword} = $value;	# add to SRIF hash
	    } else {
		push @Akas, $value;	# add to Akas array
	    }
        }
    close (SRFFILE);

    $RequestFile = $SRIF{RequestList};
    $ResponseFile = $SRIF{ResponseList};

}

############################################
# read Request file
############################################
sub readRequestList {

    logged("Reading Request file $RequestFile.") if ($Debug);
    
    open(REQFILE, "<$RequestFile")
	    or die ("Could not open Request File $RequestFile.");
	@FREQ = <REQFILE>;
    close(REQFILE);


}

############################################
# send response
############################################
sub sendResponse {

# $ResponseFile is the filename of the response list file.  One
# file per line, including drives/paths to the file.  The first
# character defnes the way the mailer should act after sending that
# file:
#  = erase file if successfully sent
#  + do not erase the file
#  - erase the file in any case

    logged("Sending response to $SRIFFILE") if ($Debug);
    
#  Send Default file if any FREQ is unfullfilled
    &sendDefaultFile();  

}

############################################
# send Default File
############################################
sub sendDefaultFile {

    my $keep = "+";  # keep file after sending.
    
#  If cannot locate any of the requested files, send a txt file back 
# saying so & add the path to that in the response list.  Initially,
# this will be the list of "magic" names for file requests;  but will
# also want to send a message file or packet back.

    logged("Sending default file $DefaultFile") if ($Debug);
  
    open (RSPFILE, ">>$ResponseFile")
		or die ("Could not open Response file $ResponseFile.");
#        print RSPFILE ("+",$DefaultFile,"\n");
        print RSPFILE ($keep,$DefaultFile,"\n");
    close(RSPFILE);

}
############################################
# send response packet back
############################################
sub sendPacketResponse {

    my $keep = "=";  # do not keep packet file if successfully sent.
    my ($Sec, $Min, $Hour, $Day, $Mon, $Year) = localtime();

    #   need to parse this from the $ResponseFile
    my $Outdir ="/var/spool/ftn/out"; 

    logged("Sending Response Message packet") if ($Debug);
  

    # create packet file name
    my $PktFile = sprintf("%s/%02d%02d%02d%02d.PKT",$Outdir,$Day,$Hour,$Min,$Sec);


    &createhuskypkt($PktFile);

    open (RSPFILE, ">>$ResponseFile")
		or die ("Could not open Response file $ResponseFile.");
        print RSPFILE ($keep,$PktFile,"\n");
    close(RSPFILE);

}


############################################
#    &createhuskypkt($PktFile);
############################################
sub createhuskypkt {

#Usage:
#txt2pkt -xf "<pkt from address>" -xt "<pkt to address>"  \
# -af "<from address>" -at "<to address>" \
# -nf "<from name>" -nt "<to name>" \
# -e "echo name" -p "password" -t "tearline" -o "origin" \
# -s "subject" -d "<directory>" <text file>

    my($pktfile) = @_;	# need to localize?

#    logged("Create packet using Husky project utility.") if ($Debug);
    
    logged("Creating pkt using Husky project utility not yet implemented.") if ($Debug);
    
    
}


############################################
# cleanup
############################################
sub cleanup {

    logged("Removing Request file $RequestFile.") if ($Debug);
    
    unlink $RequestFile;
    
}
############################################
# Logging
############################################

sub logged {

    my(@text) = @_;

#    local(*F);
#    my @x;

    my $progid="SRIF";

#    my @moy = ('Jan','Feb','Mar','Apr','May','Jun',
#	        'Jul','Aug','Sep','Oct','Nov','Dec');

#    print "$progid @text\n" if($opt_v);

    &logging($Logfile, $progid, @text);

#    # write to the log file#
#    if($LOGFILE eq "stdout") {
#        open(F, ">&STDOUT") || die "$progid: can't open log $LOGFILE\n";
#    }
#    elsif($LOGFILE eq "stderr") {
#        open(F, ">&STDERR") || die "$progid: can't open log $LOGFILE\n";
#    }
#    else {
#        open(F, ">>$LOGFILE") || die "$progid: can't open log $LOGFILE\n";
#    }
	
#    @x = localtime;
#    printf F "%s %02d %02d:%02d:%02d ",
#	   $moy[$x[4]], $x[3], $x[2], $x[1], $x[0]; 
#    print F "$progid @text\n";
    
#    close(F);

}

